<?php

/**
 * @file
 *
 * Implements a sendProfile object for newsletter distribution.
 */

class sendNewsProfile extends sendProfile {
  public $handler = 'send_news';

  public $lists = array();
  public $mode = 'news';
  public $from_element = 'news_sender';
  public $to_element = 'news_mlm';
  public $message_element = 'send_message_compose';
  public $compose_advanced = TRUE;
  public $sender_editable = TRUE;

  public function access() {
    // Check permissions for the generic "send any news" permission.
    if (user_access('send any news')) return TRUE;

    // Check permissions for this specific profile.
    return user_access('send '. $this->name() .' news');
  }

  public function availableLists() {
    foreach (mlm_lists('Announcement') as $list => $mlm) {
      $options[$list] = $mlm->title;
    }
    return $options;
  }

  public function lists() {
    return $this->lists;
  }

  public function setLists($lists) {
    $this->lists = $lists;
    $this->setRecipients($lists);
  }

  public function setRecipients($values) {
    if ($values) {
      foreach ($values as $contact) {
        if (is_numeric($contact) && $contact) $this->addRecipient(array('lid' => $contact));
      }
    }
  }

  /**
   * Function to redirect the user after delivering a message.
   */
  public function redirect() {
    // Go to the message tracking page if it exists.
    if (isset($this->send) && module_exists('send_track')) {
      return 'admin/reports/send/' . $this->send->sid;
    }

    // Alternatively, set a message and go to the front page.
    drupal_set_message("Newsletter delivered successfully.");
    return '<front>';
  }

  function send() {
    // Rely on the main "send" functionality, but register it against limits.
    if (parent::send()) flood_register_event("send news");
  }
}
