<?php

/**
 * @file
 *
 * Form functions for the News module.
 */

/**
 * The form page for user-initiated Newsletter activities.
 */
function news_form($form_state, $nids = array()) {
  if (!$profile = $form_state['storage']['send_profile']) {
    $profile = (object) send_profile_load('news');
    $profile->nids = ($nids && !is_array($nids)) ? explode(' ', $nids) : $nids;
    $profile->message_element = 'send_message_compose';
    $profile->compose_advanced = TRUE;
    $profile->action = request_uri();
  }

  if (isset($form_state['clicked_button'])) {
    if ($form_state['clicked_button']['#value'] == t('Edit')) {
      $form_state['storage']['send_profile']->message_element = 'send_message_edit';
    }
    elseif ($form_state['clicked_button']['#value'] == t('Compose')) {
      $form_state['storage']['send_profile']->message_element = 'send_message_compose';
      $form_state['storage']['send_profile']->compose_advanced = TRUE;
    }
  }

  // Ensure that the *original* form action is used, not an AHAH-rewritten one.
  if (isset($form_state['storage']['send_profile']->action)) {
    $form['#action'] = $form_state['storage']['send_profile']->action;
  }

  $form['send'] = array(
    '#type' => 'send',
    '#send_profile' => $profile,
  );

  $form['extra']['compose'] = array(
    '#type' => 'submit',
    '#value' => t('Compose'),
    '#submit' => array('send_submit_refresh'),
    '#access' => $profile->editable('body'),
  );

  $form['extra']['edit'] = array(
    '#type' => 'submit',
    '#value' => t('Edit'),
    '#submit' => array('send_submit_refresh'),
    '#access' => $profile->editable('body'),
  );

  $form['buttons']['test'] = array(
    '#type' => 'submit',
    '#value' => t('Send test message'),
    '#submit' => array('news_form_test_delivery'),
  );
  $form['buttons']['submit'] = array(
    '#type' => 'submit', '#value' => t('Send'),
  );

  return $form;
}

/**
 * A #process handler for the news_mlm form element.
 */
function news_mlm_element_process($element, $edit, &$form_state, $form) {
  $profile =& $form_state['storage']['send_profile'];

  $element['lists'] = array(
    '#parents'       => array('send', 'lists'),
    '#type'          => 'checkboxes',
    '#title'         => t('Mailing lists'),
    '#options'       => $profile->availableLists(),
    '#default_value' => $profile->lists(),
    '#required'      => $element['#required'],
  );
  return $element;
}

/**
 * A #process handler for the news_sender form element.
 */
function news_sender_element_process($element, $edit, &$form_state, $form) {
  $element['name'] = array(
    '#type'          => 'textfield',
    '#title'         => t('From name'),
    '#description'   => t('This is who your message will come from. Use something recognizable, like your site name.'),
    '#default_value' => variable_get('site_name', 'Drupal'),
  );
  $element['mail'] = array(
    '#type'          => 'textfield',
    '#title'         => t('From E-mail'),
    '#default_value' => variable_get('site_mail', ''),
  );
  return $element;
}

/**
 * An implementation of form_type_hook_value for news_sender elements.
 */
function form_type_news_sender_value(&$element, $edit = array()) {
  if (isset($edit['mail']) && isset($edit['name'])) {
    return array(
      'mail' => $edit['mail'],
      'name' => $edit['name'],
    );
  }
}

/**
 * A submit handler for the news form that delivers a test message to the admin.
 */
function news_form_test_delivery($form, &$form_state) {
  global $user;
  $profile =& $form_state['storage']['send_profile'];
  $message = $profile->message();

  mimemail($profile->sender(), $user, $message['subject'], $message['body']);
  drupal_set_message(t('Test message sent to @mail', array('@mail' => $user->mail)));
}
